@@ -63,7 +63,7 @@ from .path import (
     ContentFilepath,
     CSVpath,
 )
-from .threading import Thread
+from .threading import Thread, Tail
 from .output import Capture
 from .server import PathServer, CookieServer, CallbackServer
 from .service import Upstart, InitD, Systemd
@@ -83,7 +83,7 @@ from .test import (
 from .image import make_png
 
 
-__version__ = '1.4.2'
+__version__ = '1.4.4'
 
 
 # get rid of "No handler found" warnings (cribbed from requests)
@@ -265,6 +265,25 @@ def capture(stdout=True, stderr=True, loggers=True, *args, **kwargs):
     return c(*args, **kwargs)
 
 
+def tail(path, stream=None, encoding="UTF-8", **kwargs):
+    """Tail/follow path in a separate thread
+
+    :Example:
+        testdata.tail("/path/to/tail")
+
+    :param path: string, the path of the file you want to tail/follow
+    :param stream: io.IOBase, a file object with a write method
+    :param encoding: string, the encoding of lines
+    :param **kwargs:
+        prefix -- by default prefix is the path basename, but you can set
+            something custom here
+    """
+
+    t = Tail(path, stream, encoding, **kwargs)
+    t.start()
+    return t
+
+
 def yes(specifier=0):
     """
     Decide if we should perform this action, this is just a simple way to do something
@@ -1070,16 +1089,24 @@ def get_unique_float(min_size=None, max_size=None):
 get_uniq_float = get_unique_float
 
 
-def get_digits(count):
+def get_digits(count, n=None):
     """return a string value that contains count digits
 
     :param count: int, how many digits you want, so if you pass in 4, you would get
         4 digits
+    :param n: int, if you already have a value and want it to for sure by count digits
     :returns: string, this returns a string because the digits might start with
         zero
     """
     max_size = int("9" * count)
-    ret = "{{:0>{}}}".format(count).format(get_int(0, max_size))
+
+    if n is None:
+        n = get_int(0, max_size)
+    else:
+        if n > max_size:
+            raise ValueError("n={} has more than {} digits".format(n, count))
+
+    ret = "{{:0>{}}}".format(count).format(n)
     return ret
 get_digit = get_digits
 get_count_digits = get_digits
@@ -1598,6 +1625,7 @@ def get_last_name(is_unicode=None):
         name = '{}-{}'.format(name, get_last_name(is_unicode))
 
     return name.capitalize()
+get_lastname = get_last_name
 get_surname = get_last_name
 
 
@@ -1918,6 +1946,12 @@ def get_past_datetime(now=None):
 get_past_dt = get_past_datetime
 get_passed_datetime = get_past_datetime
 get_before_datetime = get_past_datetime
+get_past_date_time = get_past_datetime
+
+
+def get_past_date(now=None):
+    dt = get_past_datetime(now)
+    return datetime.date(dt.year, dt.month, dt.day)
 
 
 def get_future_datetime(now=None):
@@ -1934,6 +1968,13 @@ def get_future_datetime(now=None):
     )
 get_future_dt = get_future_datetime
 get_after_dt = get_future_datetime
+get_after_date_time = get_future_datetime
+get_future_date_time = get_future_datetime
+
+
+def get_future_date(now=None):
+    dt = get_future_datetime(now)
+    return datetime.date(dt.year, dt.month, dt.day)
 
 
 def get_between_datetime(start, stop=None):
@@ -1973,6 +2014,12 @@ def get_between_datetime(start, stop=None):
 
     return start + datetime.timedelta(**kwargs)
 get_between_dt = get_between_datetime
+get_between_date_time = get_between_datetime
+
+
+def get_between_date(start, stop=None):
+    dt = get_between_datetime(start, stop)
+    return datetime.date(dt.year, dt.month, dt.day)
 
 
 def get_interpreter():
